<?php
/**
 * Podcast list widgets
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class PodPro_Addon_Widget_Podcast_List extends Widget_Base {

	public function get_name() {
		return 'podpro-addon-podcast-list';
	}

	public function get_title() {
		return esc_html__( 'Podcast List', 'podpro-addon' );
	}

	public function get_icon() {
		return 'eicon-sidebar';
	}

	public function get_keywords() {
		return [ 'blog', 'podcast' ];
	}

	public function get_categories() {
		return [ 'PodPro_addon_elements' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_post',
			[
				'label' => esc_html__( 'Podcast List', 'podpro-addon' ),
			]
		);

		$this->add_control(
			'count',
			[
				'label'         => esc_html__( 'Podcasts Per Page', 'podpro-addon' ),
				'description'   => esc_html__( 'You can enter "-1" to display all items.', 'podpro-addon' ),
				'type'          => Controls_Manager::TEXT,
				'default'       => '5',
				'label_block'   => true,
			]
		);

		$this->add_control(
			'order',
			[
				'label'         => esc_html__( 'Order', 'podpro-addon' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''          => esc_html__( 'Default', 'podpro-addon' ),
					'DESC'      => esc_html__( 'DESC', 'podpro-addon' ),
					'ASC'       => esc_html__( 'ASC', 'podpro-addon' ),
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'         => esc_html__( 'Order By', 'podpro-addon' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''              => esc_html__( 'Default', 'podpro-addon' ),
					'date'          => esc_html__( 'Date', 'podpro-addon' ),
					'title'         => esc_html__( 'Title', 'podpro-addon' ),
					'name'          => esc_html__( 'Name', 'podpro-addon' ),
					'modified'      => esc_html__( 'Modified', 'podpro-addon' ),
					'author'        => esc_html__( 'Author', 'podpro-addon' ),
					'rand'          => esc_html__( 'Random', 'podpro-addon' ),
					'ID'            => esc_html__( 'ID', 'podpro-addon' ),
					'comment_count' => esc_html__( 'Comment Count', 'podpro-addon' ),
					'menu_order'    => esc_html__( 'Menu Order', 'podpro-addon' ),
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();

		// Vars
		$posts_per_page = $settings['count'];
		$order 			= $settings['order'];
		$orderby  		= $settings['orderby'];

		$args = array(
			'posts_per_page'    => $posts_per_page,
			'post_type'         => 'podcast',
			'order'             => $order,
			'orderby'           => $orderby
		);

		// Build the WordPress query
		$podcast = new \WP_Query( $args );

		// Output posts
		if ( $podcast->have_posts() ) :

			// Wrapper classes
			$wrap_classes = array( 'posts-list' );
			$wrap_classes = implode( ' ', $wrap_classes );
			?>

			<div class="<?php echo esc_attr( $wrap_classes ); ?>">

				<?php

				// Start loop
				while ( $podcast->have_posts() ) : $podcast->the_post(); ?>

					<?php get_template_part( 'partials/content/content', 'list' ); ?>

				<?php
				// End entry loop
				endwhile; ?>

			</div><!-- .posts -->

			<?php
			// Reset the post data to prevent conflicts with WP globals
			wp_reset_postdata();

		else : ?>

			<?php get_template_part( 'partials/content/content', 'none' ); ?>

		<?php endif; ?>

	<?php
	}

}

Plugin::instance()->widgets_manager->register_widget_type( new PodPro_Addon_Widget_Podcast_List() );
