<?php
/**
 * Helper functions
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// The Metabox class
if ( ! class_exists( 'PodPro_Addon_Functions' ) ) {

	/**
	 * Helper functions.
	 *
	 * @since  1.0.0
	 * @access public
	 */
	final class PodPro_Addon_Functions {

		/**
		 * Sets up initial actions.
		 *
		 * @since 1.0.0
		 */
		private function setup_actions() {

			// Add extra user fields
			add_filter( 'user_contactmethods', array( $this, 'user_fields' ) );

		}

		/**
		 * Add new user fields.
		 */
		public function user_fields( $contactmethods ) {

			$contactmethods['twitter']     = esc_html__( 'Twitter URL', 'podpro-addon' );
			$contactmethods['facebook']    = esc_html__( 'Facebook URL', 'podpro-addon' );
			$contactmethods['gplus']       = esc_html__( 'Google Plus URL', 'podpro-addon' );
			$contactmethods['instagram']   = esc_html__( 'Instagram URL', 'podpro-addon' );
			$contactmethods['pinterest']   = esc_html__( 'Pinterest URL', 'podpro-addon' );
			$contactmethods['linkedin']    = esc_html__( 'Linkedin URL', 'podpro-addon' );
			$contactmethods['dribbble']    = esc_html__( 'Dribbble URL', 'podpro-addon' );

			return $contactmethods;
		}

		/**
		 * Returns the instance.
		 *
		 * @since  1.0.0
		 * @access public
		 * @return object
		 */
		public static function get_instance() {
			static $instance = null;
			if ( is_null( $instance ) ) {
				$instance = new self;
				$instance->setup_actions();
			}
			return $instance;
		}

		/**
		 * Constructor method.
		 *
		 * @since  1.0.0
		 * @access private
		 * @return void
		 */
		private function __construct() {}

	}

	PodPro_Addon_Functions::get_instance();

}
